@@ -11,12 +11,15 @@ import urllib.parse
 
 import requests
 
+from simple_ado.audit import ADOAuditClient
 from simple_ado.builds import ADOBuildClient
 from simple_ado.exceptions import ADOException
+from simple_ado.identities import ADOIdentitiesClient
 from simple_ado.git import ADOGitClient
 from simple_ado.graph import ADOGraphClient
 from simple_ado.governance import ADOGovernanceClient
 from simple_ado.http_client import ADOHTTPClient, ADOResponse
+from simple_ado.pipelines import ADOPipelineClient
 from simple_ado.pools import ADOPoolsClient
 from simple_ado.pull_requests import ADOPullRequestClient
 from simple_ado.security import ADOSecurityClient
@@ -41,10 +44,13 @@ class ADOClient:
 
     http_client: ADOHTTPClient
 
+    audit: ADOAuditClient
     builds: ADOBuildClient
     git: ADOGitClient
     governance: ADOGovernanceClient
     graph: ADOGraphClient
+    identities: ADOIdentitiesClient
+    pipelines: ADOPipelineClient
     pools: ADOPoolsClient
     security: ADOSecurityClient
     user: ADOUserClient
@@ -75,10 +81,13 @@ class ADOClient:
             extra_headers=extra_headers,
         )
 
+        self.audit = ADOAuditClient(self.http_client, self.log)
         self.builds = ADOBuildClient(self.http_client, self.log)
+        self.identities = ADOIdentitiesClient(self.http_client, self.log)
         self.git = ADOGitClient(self.http_client, self.log)
         self.governance = ADOGovernanceClient(self.http_client, self.log)
         self.graph = ADOGraphClient(self.http_client, self.log)
+        self.pipelines = ADOPipelineClient(self.http_client, self.log)
         self.pools = ADOPoolsClient(self.http_client, self.log)
         self.security = ADOSecurityClient(self.http_client, self.log)
         self.user = ADOUserClient(self.http_client, self.log)
@@ -167,7 +176,11 @@ class ADOClient:
         )
 
     def list_all_pull_requests(
-        self, *, branch_name: Optional[str] = None, project_id: str, repository_id: str,
+        self,
+        *,
+        branch_name: Optional[str] = None,
+        project_id: str,
+        repository_id: str,
     ) -> ADOResponse:
         """Get the pull requests for a branch from ADO.
 
