@@ -7,14 +7,12 @@
 
 import logging
 
-from simple_ado.context import ADOContext
 from simple_ado.http_client import ADOHTTPClient
 
 
 class ADOBaseClient:
-    """Base context for ADO API.
+    """Base client for ADO API.
 
-    :param context: The context information for the client
     :param http_client: The HTTP client to use for the client
     :param log: The logger to use
     """
@@ -22,14 +20,9 @@ class ADOBaseClient:
     log: logging.Logger
 
     http_client: ADOHTTPClient
-    context: ADOContext
 
-    def __init__(
-        self, context: ADOContext, http_client: ADOHTTPClient, log: logging.Logger
-    ) -> None:
+    def __init__(self, http_client: ADOHTTPClient, log: logging.Logger) -> None:
         """Construct a new base client object."""
 
         self.log = log
-
-        self.context = context
         self.http_client = http_client
