@@ -91,6 +91,22 @@ class ADOGitClient(ADOBaseClient):
         response_data = self.http_client.decode_response(response)
         return self.http_client.extract_value(response_data)
 
+    def get_repository(self, *, project_id: str, repository_id: str) -> ADOResponse:
+        """Get a repository from the project.
+
+        :param str project_id: The ID of the project
+        :param str repository_id: The ID of the repository
+
+        :returns: The ADO response with the data in it
+        """
+        self.log.debug(f"Getting repository {repository_id}")
+        request_url = (
+            f"{self.http_client.api_endpoint(project_id=project_id)}/git/"
+            + f"repositories/{repository_id}?api-version=6.0"
+        )
+        response = self.http_client.get(request_url)
+        return self.http_client.decode_response(response)
+
     def get_status(self, *, sha: str, project_id: str, repository_id: str) -> ADOResponse:
         """Set a status on a PR.
 
@@ -172,7 +188,12 @@ class ADOGitClient(ADOBaseClient):
         return self.http_client.decode_response(response)
 
     def diff_between_commits(
-        self, *, base_commit: str, target_commit: str, project_id: str, repository_id: str,
+        self,
+        *,
+        base_commit: str,
+        target_commit: str,
+        project_id: str,
+        repository_id: str,
     ) -> ADOResponse:
         """Get the diff between two commits.
 
@@ -220,7 +241,12 @@ class ADOGitClient(ADOBaseClient):
             skip += 100
 
     def download_zip(
-        self, *, branch: str, output_path: str, project_id: str, repository_id: str,
+        self,
+        *,
+        branch: str,
+        output_path: str,
+        project_id: str,
+        repository_id: str,
     ) -> None:
         """Download the zip of the branch specified.
 
@@ -309,7 +335,7 @@ class ADOGitClient(ADOBaseClient):
 
         # pylint: disable=too-complex
 
-        self.log.debug(f"Getting refs")
+        self.log.debug("Getting refs")
 
         request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}/refs?"
 
@@ -357,6 +383,26 @@ class ADOGitClient(ADOBaseClient):
 
     # pylint: enable=too-many-locals
 
+    def get_stats_for_branch(
+        self, *, project_id: str, repository_id: str, branch_name: str
+    ) -> ADOResponse:
+        """Get the stats for a branch.
+
+        :param str project_id: The ID of the project
+        :param str repository_id: The ID for the repository
+        :param str branch_name: The name of the branch to get the stats for
+
+        :returns: The ADO response with the data in it
+        """
+
+        self.log.debug("Getting stats")
+
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}"
+        request_url += f"/stats/branches?name={branch_name}&api-version=6.0"
+
+        response = self.http_client.get(request_url)
+        return self.http_client.decode_response(response)
+
     def get_commit(
         self,
         *,
@@ -390,7 +436,11 @@ class ADOGitClient(ADOBaseClient):
         return self.http_client.decode_response(response)
 
     def update_refs(
-        self, *, updates: List[ADOReferenceUpdate], project_id: str, repository_id: str,
+        self,
+        *,
+        updates: List[ADOReferenceUpdate],
+        project_id: str,
+        repository_id: str,
     ) -> ADOResponse:
         """Update a list of references.
 
@@ -433,24 +483,24 @@ class ADOGitClient(ADOBaseClient):
     class VersionControlRecursionType(enum.Enum):
         """Specifies the level of recursion to use when getting an item."""
 
-        full = "full"
-        none = "none"
-        one_level = "oneLevel"
-        one_level_plus_nested_empty_folders = "oneLevelPlusNestedEmptyFolders"
+        FULL = "full"
+        NONE = "none"
+        ONE_LEVEL = "oneLevel"
+        ONE_LEVEL_PLUS_NESTED_EMPTY_FOLDERS = "oneLevelPlusNestedEmptyFolders"
 
     class GitVersionOptions(enum.Enum):
         """Version options."""
 
-        first_parent = "firstParent"
-        none = "none"
-        previous_change = "previousChange"
+        FIRST_PARENT = "firstParent"
+        NONE = "none"
+        PREVIOUS_CHANGE = "previousChange"
 
     class GitVersionType(enum.Enum):
         """Version type. Determines how the ID of an item is interpreted."""
 
-        branch = "branch"
-        commit = "commit"
-        tag = "tag"
+        BRANCH = "branch"
+        COMMIT = "commit"
+        TAG = "tag"
 
     # pylint: disable=too-many-locals
     def get_item(
@@ -489,7 +539,7 @@ class ADOGitClient(ADOBaseClient):
         :returns: The ADO response with the data in it
         """
 
-        self.log.debug(f"Getting item")
+        self.log.debug("Getting item")
 
         request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}/items?"
 
@@ -532,10 +582,10 @@ class ADOGitClient(ADOBaseClient):
     class BlobFormat(enum.Enum):
         """The type of format to get a blob in."""
 
-        json = "json"
-        zip = "zip"
-        text = "text"
-        octetstream = "octetstream"
+        JSON = "json"
+        ZIP = "zip"
+        TEXT = "text"
+        OCTETSTREAM = "octetstream"
 
     def get_blob(
         self,
@@ -563,7 +613,7 @@ class ADOGitClient(ADOBaseClient):
         :returns: The ADO response with the data in it
         """
 
-        self.log.debug(f"Getting blob")
+        self.log.debug("Getting blob")
 
         request_url = self.http_client.api_endpoint(
             is_default_collection=False, project_id=project_id
@@ -590,14 +640,19 @@ class ADOGitClient(ADOBaseClient):
 
         response = self.http_client.get(request_url)
 
-        if blob_format == ADOGitClient.BlobFormat.text:
+        if blob_format == ADOGitClient.BlobFormat.TEXT:
             self.http_client.validate_response(response)
             return response.text
 
         return self.http_client.decode_response(response)
 
     def get_blobs(
-        self, *, blob_ids: List[str], output_path: str, project_id: str, repository_id: str,
+        self,
+        *,
+        blob_ids: List[str],
+        output_path: str,
+        project_id: str,
+        repository_id: str,
     ) -> ADOResponse:
         """Get a git item.
 
@@ -611,7 +666,7 @@ class ADOGitClient(ADOBaseClient):
         :raises FileExistsError: If the output path already exists
         """
 
-        self.log.debug(f"Getting blobs")
+        self.log.debug("Getting blobs")
 
         request_url = self.http_client.api_endpoint(
             is_default_collection=False, project_id=project_id
